```json
{
  "title": "MathJax v3 with MathML input and HTML output",
  "author": "",
  "site": "",
  "published": ""
}
```

## MathJax v3 beta: MathML input, HTML output test

When

$$
a \neq 0
$$
 , there are two solutions to $a x^{2} + b x + c = 0$ and they are 
$$
x = \frac{- b \pm \sqrt{b^{2} - 4 a c}}{2 a} \text{ }.\text{ }
$$

## The Lorenz Equations

$$
\overset{\cdot}{x} & = \sigma \left(\right. y - x \left.\right) \\ \overset{\cdot}{y} & = \rho x - y - x z \\ \overset{\cdot}{z} & = - \beta z + x y
$$

## The Cauchy-Schwarz Inequality

$$
\left(\left(\right. \sum_{k = 1}^{n} a_{k} b_{k} \left.\right)\right)^{ 2} \leq \left(\right. \sum_{k = 1}^{n} a_{k}^{2} \left.\right) \left(\right. \sum_{k = 1}^{n} b_{k}^{2} \left.\right)
$$

## A Cross Product Formula

$$
\mathbf{V}_{1} \times \mathbf{V}_{2} = \left|\right. \mathbf{i} & \mathbf{j} & \mathbf{k} \\ \frac{\partial X}{\partial u} & \frac{\partial Y}{\partial u} & 0 \\ \frac{\partial X}{\partial v} & \frac{\partial Y}{\partial v} & 0 \left|\right.
$$

## The probability of getting

 $k$ heads when flipping $n$ coins is: 
$$
P \left(\right. E \left.\right) = \left(\right. \frac{n}{k} \left.\right) p^{k} \left(\right. 1 - p \left.\right)^{n - k}
$$

## An Identity of Ramanujan

$$
\frac{1}{\left(\right. \sqrt{\phi \sqrt{5}} - \phi \left.\right) e^{\frac{2}{5} \pi}} = 1 + \frac{e^{- 2 \pi}}{1 + \frac{e^{- 4 \pi}}{1 + \frac{e^{- 6 \pi}}{1 + \frac{e^{- 8 \pi}}{1 + \ldots}}}}
$$

## A Rogers-Ramanujan Identity

$$
1 + \frac{q^{2}}{\left(\right. 1 - q \left.\right)} + \frac{q^{6}}{\left(\right. 1 - q \left.\right) \left(\right. 1 - q^{2} \left.\right)} + \hdots = \prod_{j = 0}^{\infty} \frac{1}{\left(\right. 1 - q^{5 j + 2} \left.\right) \left(\right. 1 - q^{5 j + 3} \left.\right)} , \text{ for } \left|\right. q \left|\right. < 1 .
$$

## Maxwell's Equations

$$
\nabla \times \overset{\rightarrow}{\mathbf{B}} - \frac{1}{c} \frac{\partial \overset{\rightarrow}{\mathbf{E}}}{\partial t} & = \frac{4 \pi}{c} \overset{\rightarrow}{\mathbf{j}} \\ \nabla \cdot \overset{\rightarrow}{\mathbf{E}} & = 4 \pi \rho \\ \nabla \times \overset{\rightarrow}{\mathbf{E}} + \frac{1}{c} \frac{\partial \overset{\rightarrow}{\mathbf{B}}}{\partial t} & = \overset{\rightarrow}{0} \\ \nabla \cdot \overset{\rightarrow}{\mathbf{B}} & = 0
$$

## In-line Mathematics

Finally, while display equations look good for a page of samples, the ability to mix math and text in a paragraph is also important. This expression

$$
\sqrt{3 x - 1} + \left(\right. 1 + x \left.\right)^{2}
$$
 is an example of an inline equation. As you see, MathJax equations can be used this way as well, without unduly disturbing the spacing between lines.